##  Troubleshooting
### KPI is not calculating
If a KPI does not display a value after creation:
  * Verify that your filters are not too restrictive. Check that some fact sheets match the filter criteria.
  * Ensure that the fact sheet type you selected contains data in your workspace.
  * Wait a few minutes for the initial calculation to complete, especially for complex KPIs.


### Historical values are inconsistent
Consider creating a new KPI if you need consistent historical tracking with a new calculation formula.
### KPI is missing from a dashboard
If a KPI does not appear on a dashboard:
  * Verify that the KPI has been saved successfully in the administration area.
  * Check that you have added the KPI to a KPI panel on the dashboard.
  * Ensure you have the necessary permissions to view the dashboard or the KPI.
  * When you delete a KPI displayed on a dashboard, you get a message prompting you to adjust the list of KPIs displayed on the dashboard.
